<?php namespace FFCFCC\Shortcodes;
/**
 * FfcFootballCo2Calculator
 * Author: Micha at FFC Olympia
 */
defined('FFCFCC_DIR') or die("you do not have acces to this page!");

/**
 * Description of co2 calculator
 *
 * @author Micha
 */
class Co2Calculator {
    
    /**
     * [co2calculator][/co2calculator]
     * @param type $atts
     * @param type $content
     * @param type $tag
     * @return type
     */
    public function getCalculator($atts = [], $content = null, $tag = '') {
        $wporg_atts = $this->verifyAttributes($atts, $tag);
        
        $rows = $this->insertDataIntoRow();
        $template = $this->getTable();
        $value = $this->getTitle();
        $value .= $this->insertRowsIntoHtmlTable($template, $rows);
        $value .= $this->getPartner();
        
        return $value;
    }
    
    private function verifyAttributes($atts = [], $tag = '') {
         // normalize attribute keys, lowercase
        $atts2 = array_change_key_case( (array) $atts, CASE_LOWER );
    
        // override default attributes with user attributes
        $wporg_atts = shortcode_atts(
            array(
                'team' => '',
                'saison' => '',
            ), $atts2, $tag
        );
        
        return $wporg_atts;
    }
    
    private function secureContent($content = null) {
        $value = "";
        // enclosing tags
        if ( ! is_null( $content ) ) {
            // secure output by executing the_content filter hook on $content
            $value .= apply_filters( 'the_content', $content );

            // run shortcode parser recursively
            $value .= do_shortcode( $content );
        }
        return $value;
    }
    
    private function insertDataIntoRow() {
        $row = $this->getRow();
        $temp = str_replace("[distanz]", $this->getDistanz(), $row);
        $temp2 = str_replace("[verkehrsmittel]", $this->getVerkehrsmittel(), $temp);
        $temp3 = str_replace("[anzahl]", $this->getAnzahl(), $temp2);
        $temp4 = str_replace("[emissionen]", $this->getEmissionen(), $temp3);
        $temp5 = str_replace("[kompensation]", $this->getBaeume(), $temp4);
        
        return $temp5;
    }
    
    private function insertRowsIntoHtmlTable($template, $rows) {
        $value = str_replace("[rows]", $rows, $template);
        
        return $value;
    }
       
    private function getTitle() {
        $header = "<p><strong>".__("CO2 calculator", "ffc-football-co2-calculator").":</strong></p>";
        
        return $header;
    }
    
    private function getDistanz() {
        $distanz = "<select id='ffcfcc_distanz' name='ffcfcc_distanz'>";
        
        for ($i=1; $i <= 200; $i++) {
            $distanz .= "<option value='".$i."'>" .$i."</option>";
        }
        $distanz .= "</select> km";
        
        return $distanz;
    }
    
    private function getVerkehrsmittel() {
        $verkehrsmittel = "<select id='ffcfcc_verkehrsmittel' name='ffcfcc_verkehrsmittel'>";
        $verkehrsmittel .= "<option value='Pkw'>".__("Car", "ffc-football-co2-calculator")."</option>";
        $verkehrsmittel .= "<option value='ÖPNV'>".__("Public transport", "ffc-football-co2-calculator")."</option>";
        $verkehrsmittel .= "<option value='Fahrrad'>".__("Bicycle", "ffc-football-co2-calculator")."</option>";
        $verkehrsmittel .= "</select>";
        
        return $verkehrsmittel;
    }
    
    private function getAnzahl() {
        $anzahl = "<select id='ffcfcc_anzahl' name='ffcfcc_anzahl'>";
        
        for ($i=1; $i <= 5; $i++) {
            $anzahl .= "<option value='".$i."'>" .$i."</option>";
        }
        $anzahl .= "</select> ".__("persons", "ffc-football-co2-calculator");
        
        return $anzahl;
    }
    
    private function getEmissionen() {
        return "<div id='ffcfcc_co2emissionen'></div>";
    }
        
    private function getBaeume() {
        return "<div id='ffcfcc_kompensation'></div>";
    }
    
    private function getPartner() {
        $partner = "<p>".__("Trees and gardeners are available among others from", "ffc-football-co2-calculator").":<br/>";
        $partner .= "<a href='https://sports4trees.com/mitmachen/' target='_blank'><img width='210' src='".plugin_dir_url( __FILE__ ) ."../init/images/Sports-4-Future-Logo.png'></a>";
        $partner .= "<a href='https://donate.plant-for-the-planet.org/?to=one-student-one-tree&units=4&s=ffc-football-calculator' target='_blank'><img width='210' src='".plugin_dir_url( __FILE__ ) ."../init/images/pftp-projects/OneStudentOneTree.png'></a>";
        $partner .= "<a href='https://donate.plant-for-the-planet.org/?to=yucatan&units=2&s=ffc-football-calculator' target='_blank'><img width='210' src='".plugin_dir_url( __FILE__ ) ."../init/images/pftp-projects/YucatanRestoration.png'></a>";
        $partner .= "</p>";
        
        return $partner;
    }
    
    private function getRow() {
        $row = "<tr>" .
            "<td data-label='".__("Distance", "ffc-football-co2-calculator")."'>[distanz]</td>" .
            "<td data-label='".__("Mode of transportation", "ffc-football-co2-calculator")."'>[verkehrsmittel]</td>" .
            "<td data-label='".__("Quantity", "ffc-football-co2-calculator")."'>[anzahl]</td>" .
            "<td data-label='".__("CO2 emissions", "ffc-football-co2-calculator")."'>[emissionen]</td>" .
            "<td data-label='".__("Strengthen biodiversity", "ffc-football-co2-calculator")."'>[kompensation]</td>" .
            "</tr>";
        
        return $row;
    }
    
    private function getTable() {
        $table = "<table class='RespTable'>" .
                "<thead>" . 
                "<tr>" .
                "<th style='width: 20%'>".__("Distance<br/>(round trip)", "ffc-football-co2-calculator")."</th>" .
                "<th style='width: 15%'>".__("Mode of transportation", "ffc-football-co2-calculator")."</th>" .
                "<th style='width: 17%'>".__("Quantity", "ffc-football-co2-calculator")."</th>" .
                "<th style='width: 25%'>".__("CO2 emissions<br/>(in kg per person)", "ffc-football-co2-calculator")."</th>" .
                "<th style='width: 30%'>".__("Strengthen biodiversity with", "ffc-football-co2-calculator")."</th>" .
                "</tr>" .
                "</thead>" .
                "<tbody>" .
                "[rows]" . 
                "</tbody>" .
                "</table>";
        
        return $table;
    }
}
